// ** React Imports
import React, {
    useState,
    useEffect,
    forwardRef,
    useCallback,
    Fragment,
} from "react";
import Icon from "@mdi/react";
import { mdiChevronRight, mdiClose } from "@mdi/js";

// ** MUI Imports
import Box from "@mui/material/Box";
import Drawer from "@mui/material/Drawer";
import Select from "@mui/material/Select";
import Button from "@mui/material/Button";
import MenuItem from "@mui/material/MenuItem";
import TextField from "@mui/material/TextField";
import InputLabel from "@mui/material/InputLabel";
import Autocomplete from "@mui/material/Autocomplete";
import Typography from "@mui/material/Typography";
import FormControl from "@mui/material/FormControl";
import FormHelperText from "@mui/material/FormHelperText";
import Switch from "@mui/material/Switch";
import FormControlLabel from "@mui/material/FormControlLabel";
import { CircularProgress } from "@mui/material";
import { useDropzone } from "react-dropzone";

// ** Third Party Imports
import DatePicker from "react-datepicker";
import { useForm, Controller } from "react-hook-form";
import { router, usePage } from "@inertiajs/react";

// ** Icons Imports
import Close from "mdi-material-ui/Close";
// import DeleteOutline from "mdi-material-ui/DeleteOutline";
// import InputError from "@/Components/InputErrorCustom";
import DatePickerWrapper from "@/Components/react-datepicker";
// ** Styled Components
import "react-datepicker/dist/react-datepicker.css";

const capitalize = (string) =>
    string && string[0].toUpperCase() + string.slice(1);

var date = new Date();
date.setDate(date.getDate() + 30);
// Format the result as a string (e.g., "YYYY-MM-DD")
const year = date.getFullYear();
const month = String(date.getMonth() + 1).padStart(2, "0");
const day = String(date.getDate()).padStart(2, "0");
const futureDate = `${year}-${month}-${day}`;

const image_types = [
    { id: 1, name: "breadcumb_image" },
    { id: 1, name: "image1" },
    { id: 1, name: "image2" },
    { id: 1, name: "video" },
];

const nextDay = new Date(new Date().getTime() + 24 * 60 * 60 * 1000);

const nextMonth =
    date.getMonth() == 9
        ? new Date(date.getFullYear() + 1, 0, 1)
        : new Date(date.getFullYear(), date.getMonth() + 1, 1);

const prevMonth =
    date.getMonth() == 9
        ? new Date(date.getFullYear() - 1, 0, 1)
        : new Date(date.getFullYear(), date.getMonth() - 1, 1);

//

const AddImage = (props) => {
    const {
        currentItem,
        selectedEvent,
        drawerWidth,
        addEventSidebarOpen,
        handleAddEventSidebarToggle,
    } = props;
    // ** Props

    const { flash } = usePage().props;

    const [openProgress, setOpenProgress] = useState(false);

    const [selectedFile, setSelectedFile] = useState(undefined);
    const [values, setValues] = useState(undefined);
    const [preview, setPreview] = React.useState("");
    const [type, setType] = React.useState(null);
    var defaultState = {};
    useEffect(() => {
        if (flash && flash.success) {
            setOpenProgress(false);
            setSelectedFile(undefined);
            // setOpenDialog(false);
        }
    }, [flash]);
    useEffect(() => {
        // console.log("CurrentItem", currentItem);
    }, [currentItem]);

    const handleSidebarClose = async () => {
        setValues(defaultState);
        clearErrors();
        handleAddEventSidebarToggle();
    };

    const {
        control,
        setValue,
        clearErrors,
        handleSubmit,
        formState: { errors },
    } = useForm({ defaultValues: defaultState });

    const onSubmit = (data) => {
        const listingData = {
            id: currentItem.id,

            image: selectedFile,
            video: selectedFile,
            type: type,
        };

        setOpenProgress(true);
        // console.log("valuesss", listingData);
        // return;
        router.post(
            "/dashboard/add-blog-images",
            { ...listingData },
            {
                headers: {
                    "Content-Type": "multipart/form-data",
                },
            }
        );
    };

    const onDrop = React.useCallback((acceptedFiles) => {
        setSelectedFile(acceptedFiles[0]);
    }, []);

    useEffect(() => {
        if (!selectedFile) {
            setPreview(undefined);
            return;
        }

        const objectUrl = URL.createObjectURL(selectedFile);
        setPreview(objectUrl);

        return () => URL.revokeObjectURL(objectUrl);
    }, [selectedFile]);

    const { getRootProps, getInputProps, isDragActive } = useDropzone({
        accept: {
            "image/jpeg": [],
            "image/png": [],
            "image/gif": [],
            "image/webp": [],
            "video/mp4": [],
            "video/mkv": [],
        },
        onDrop,
    });

    return (
        <Drawer
            anchor="right"
            open={addEventSidebarOpen}
            onClose={handleSidebarClose}
            ModalProps={{ keepMounted: true }}
            sx={{ "& .MuiDrawer-paper": { width: ["100%", drawerWidth] } }}
        >
            <Box
                className="sidebar-header"
                sx={{
                    display: "flex",
                    justifyContent: "space-between",
                    backgroundColor: "background.default",
                    p: (theme) => theme.spacing(3, 3.255, 3, 5.255),
                }}
            >
                <Typography variant="h6">{" IMAGE"}</Typography>
                <Box sx={{ display: "flex", alignItems: "center" }}>
                    {selectedEvent !== null ? (
                        // <DeleteOutline
                        //     fontSize="small"
                        //     sx={{
                        //         cursor: "pointer",
                        //         mr: selectedEvent !== null ? 2 : 0,
                        //     }}
                        //     onClick={handleDeleteEvent}
                        // />
                        <></>
                    ) : null}
                    <Close
                        fontSize="small"
                        className="text-red-500"
                        onClick={handleSidebarClose}
                        sx={{ cursor: "pointer" }}
                    />
                </Box>
            </Box>
            <Box
                className="sidebar-body"
                sx={{ p: (theme) => theme.spacing(5, 6) }}
            >
                <DatePickerWrapper>
                    <div>
                        <FormControl fullWidth sx={{ mb: 4 }}>
                            <Autocomplete
                                disablePortal
                                className="mt-1 block w-full"
                                id="type"
                                name="type"
                                label="Type"
                                options={image_types}
                                getOptionLabel={(option) => option.name}
                                sx={{ width: 300 }}
                                onChange={(e, val) => setType(val.name)}
                                renderInput={(params) => (
                                    <TextField
                                        {...params}
                                        label="Type"
                                        name="type"
                                    />
                                )}
                            />

                            {errors.type && (
                                <FormHelperText
                                    sx={{ color: "error.main" }}
                                    id="event-title-error"
                                >
                                    This field is required
                                </FormHelperText>
                            )}
                        </FormControl>
                        <div className="flex justify-center pt-0 bg-second-500 px-8 text-gray-700">
                            <div className="mb-4">
                                <Typography
                                    variant="p"
                                    component="div"
                                    gutterBottom
                                    className="text-center"
                                >
                                    Package Image
                                </Typography>

                                <div className="">
                                    {selectedFile ? (
                                        <div className="w-48 relative my-4 border-dashed border-gray-600 border p-4">
                                            <img
                                                src={preview}
                                                className="object-cover w-40 h-40"
                                            />
                                            <div className="absolute top-2 right-2 bg-gray-300">
                                                <Icon
                                                    path={mdiClose}
                                                    size={1}
                                                    onClick={() => {
                                                        setSelectedFile(
                                                            undefined
                                                        );
                                                    }}
                                                />
                                            </div>
                                        </div>
                                    ) : (
                                        <div
                                            className="w-full my-4 h-40 border-dashed border-gray-500 border p-4"
                                            {...getRootProps()}
                                        >
                                            <input
                                                name="image"
                                                {...getInputProps()}
                                                // onChange={(e, val) => {
                                                // console.log(
                                                //     event.currentTarget
                                                //         .files[0]
                                                // );
                                                // setValues({
                                                //     ...values,
                                                //     image_full: e.target.value,
                                                // });
                                                // }}
                                            />
                                            {isDragActive ? (
                                                <p>Drop the files here ...</p>
                                            ) : (
                                                <p>
                                                    Click or drag and drop to
                                                    add image
                                                </p>
                                            )}
                                        </div>
                                    )}
                                </div>
                            </div>
                        </div>
                        <Box sx={{ display: "flex", alignItems: "center" }}>
                            {!openProgress ? (
                                <Button
                                    size="large"
                                    type="submit"
                                    variant="contained"
                                    className="w-full"
                                    sx={{ mr: 0 }}
                                    disabled={openProgress}
                                    onClick={onSubmit}
                                >
                                    Add Image
                                </Button>
                            ) : (
                                <Button
                                    size="large"
                                    variant="outlined"
                                    className="w-full"
                                    sx={{ mr: 0 }}
                                    disabled={openProgress}
                                >
                                    <CircularProgress className="text-main-500" />
                                </Button>
                            )}
                        </Box>
                    </div>
                </DatePickerWrapper>
            </Box>
        </Drawer>
    );
};

export default AddImage;
